| Title: | Seamless Access to OECD Official Development Assistance (ODA) Data |
|---|---|
| Description: | Access and Analyze Official Development Assistance (ODA) data using the OECD API <https://gitlab.algobank.oecd.org/public-documentation/dotstat-migration/-/raw/main/OECD_Data_API_documentation.pdf>. ODA data includes sovereign-level aid data such as key aggregates (DAC1), geographical distributions (DAC2A), project-level data (CRS), and multilateral contributions (Multisystem). |
| Authors: | Christoph Scheuch [aut, cre, cph] (ORCID: <https://orcid.org/0009-0004-0423-6819>) |
| Maintainer: | Christoph Scheuch <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0.9001 |
| Built: | 2026-05-26 08:14:56 UTC |
| Source: | https://github.com/tidy-intelligence/r-oecdoda |
Retrieves data from the OECD CRS dataset using specified filters, years, and optional pre-processing.
oda_get_crs( start_year = NULL, end_year = NULL, filters = NULL, pre_process = TRUE, as_grant_equivalent = FALSE )oda_get_crs( start_year = NULL, end_year = NULL, filters = NULL, pre_process = TRUE, as_grant_equivalent = FALSE )
start_year |
Integer. The starting year of the data query. If |
end_year |
Integer. The ending year of the data query. If |
filters |
List. A named list of filters to apply (e.g., donor codes, easure, flow type, unit measure, price base). Values must match OECD dotstat codes. |
pre_process |
Logical. Whether to clean and rename columns into a
standard format. If |
as_grant_equivalent |
Logical. Whether the 'flows' or 'grant equivalent' version of the CRS should be returned. |
A data frame containing OECD CRS data
oda_get_crs( start_year = 2018, end_year = 2022, filters = list( donor = c("AUT", "FRA", "USA"), recipient = "BIH", measure = 100, channel = 60000, price_base = "Q" ) )oda_get_crs( start_year = 2018, end_year = 2022, filters = list( donor = c("AUT", "FRA", "USA"), recipient = "BIH", measure = 100, channel = 60000, price_base = "Q" ) )
Retrieves data from the OECD DAC1 dataset using specified filters, years, and optional pre-processing.
oda_get_dac1( start_year = NULL, end_year = NULL, filters = NULL, pre_process = TRUE )oda_get_dac1( start_year = NULL, end_year = NULL, filters = NULL, pre_process = TRUE )
start_year |
Integer. The starting year of the data query. If |
end_year |
Integer. The ending year of the data query. If |
filters |
List. A named list of filters to apply (e.g., donor codes, easure, flow type, unit measure, price base). Values must match OECD dotstat codes. |
pre_process |
Logical. Whether to clean and rename columns into a
standard format. If |
A data frame containing OECD DAC1 data
oda_get_dac1( start_year = 2018, end_year = 2022, filters = list( donor = c("FRA", "USA"), measure = 11017, flow_type = 1160, unit_measure = "XDC", price_base = "V" ) )oda_get_dac1( start_year = 2018, end_year = 2022, filters = list( donor = c("FRA", "USA"), measure = 11017, flow_type = 1160, unit_measure = "XDC", price_base = "V" ) )
Retrieves data from the OECD DAC2A dataset using specified filters, years, and optional pre-processing.
oda_get_dac2a( start_year = NULL, end_year = NULL, filters = NULL, pre_process = TRUE )oda_get_dac2a( start_year = NULL, end_year = NULL, filters = NULL, pre_process = TRUE )
start_year |
Integer. The starting year of the data query. If |
end_year |
Integer. The ending year of the data query. If |
filters |
List. A named list of filters to apply (e.g., donor codes, easure, flow type, unit measure, price base). Values must match OECD dotstat codes. |
pre_process |
Logical. Whether to clean and rename columns into a
standard format. If |
A data frame containing OECD DAC2A data
oda_get_dac2a( start_year = 2018, end_year = 2022, filters = list( donor = "GBR", recipient = c("GTM","CHN"), measure = 106, price_base = "Q" ) )oda_get_dac2a( start_year = 2018, end_year = 2022, filters = list( donor = "GBR", recipient = c("GTM","CHN"), measure = 106, price_base = "Q" ) )
Retrieves data from the OECD Multisystem dataset using specified filters, years, and optional pre-processing.
oda_get_multisystem( start_year = NULL, end_year = NULL, filters = NULL, pre_process = TRUE )oda_get_multisystem( start_year = NULL, end_year = NULL, filters = NULL, pre_process = TRUE )
start_year |
Integer. The starting year of the data query. If |
end_year |
Integer. The ending year of the data query. If |
filters |
List. A named list of filters to apply (e.g., donor codes, easure, flow type, unit measure, price base). Values must match OECD dotstat codes. |
pre_process |
Logical. Whether to clean and rename columns into a
standard format. If |
A data frame containing OECD Multisystem data
oda_get_multisystem( start_year = 2018, end_year = 2022, filters = list( donor = "DAC", recipient = "DPGC", sector = 1000, measure = 10 ) )oda_get_multisystem( start_year = 2018, end_year = 2022, filters = list( donor = "DAC", recipient = "DPGC", sector = 1000, measure = 10 ) )
List Available Filters for an ODA Resource
oda_list_filters(resource = NULL)oda_list_filters(resource = NULL)
resource |
A character string identifying the resource
(e.g., |
A character vector of available filter names for the given resource.
oda_list_filters() oda_list_filters("DSD_DAC2@DF_DAC2A")oda_list_filters() oda_list_filters("DSD_DAC2@DF_DAC2A")